/********************************************************************
 **                   Microsoft OS/2 LAN Manager                   **
 **            Copyright(c) Microsoft Corp., 1987, 1988            **
 ********************************************************************/

/********************************************************************
 *								    *
 *  About this file ...  ERRLOG.H				    *
 *								    *
 *  This file contains information about the NetErrorLog APIs.	    *
 *								    *
 *	Function prototypes.					    *
 *								    *
 *	Data structure templates.				    *
 *								    *
 *	Definition of special values.				    *
 *								    *
 *								    *
 *  NOTE:  You must include NETCONS.H before this file, since this  *
 *	   file	depends on values defined in NETCONS.H.		    *
 *								    *
 ********************************************************************/


/**************************************************************** 
 *								*
 *	  	Function prototypes 				*
 *								*
 ****************************************************************/

extern API_FUNCTION
  NetErrorLogOpen ( const char far *, unsigned far *, char far * );

extern API_FUNCTION
  NetErrorLogClear ( const char far *, const char far *, char far * );

extern API_FUNCTION
  NetErrorLogWrite ( char far *, unsigned short, const char far *, 
					const char far *, 
  					unsigned short, const char far *, 
					unsigned short, char far * );


/**************************************************************** 
 *								*
 *	  	Data structure templates			*
 *								*
 ****************************************************************/


struct error_log {
	unsigned short	el_len;
	unsigned short  el_reserved;
	unsigned long	el_time;
	unsigned short	el_error;
        char            el_name[SNLEN+1];
	unsigned short  el_data_offset;
	unsigned short  el_nstrings;
}; /* error_log */


/**************************************************************** 
 *								*
 *	  	Special values and constants			*
 *								*
 ****************************************************************/


/***	ERRLOG_BASE is the base of error log codes,
 *	chosen to avoid conflict with OS, redirector,
 *	and netapi codes.
 */

#define ERRLOG_BASE	3100		/* NELOG errs start here */



/*
 *	Generic (could be used by more than one service)
 * 	 error log messages from 0 to 25
 */

#define NELOG_Internal_Error		(ERRLOG_BASE + 0)
	/*
	 * The operation failed because a network software error occurred.
	 */


#define NELOG_Resource_Shortage		(ERRLOG_BASE + 1)
	/*
	 * The system ran out of the resource controlled by initialization
	 *  parameter %1.
	 */

#define NELOG_Unable_To_Lock_Segment	(ERRLOG_BASE + 2)
	/*
	 * The service failed to obtain a long-term lock on the 
	 *  segment for NCBs. The error code is the data.
	 */

#define NELOG_Unable_To_Unlock_Segment	(ERRLOG_BASE + 3)
	/*
	 * The service failed to release the long-term lock on the
	 *  segment for NCBs. The error code is the data.
	 */

#define NELOG_Uninstall_Service		(ERRLOG_BASE + 4)
	/*
	 * There was an error uninstalling service %1.
	 *  The error code from NetServiceControl is the data.
	 */

#define NELOG_Init_Exec_Fail		(ERRLOG_BASE + 5)
	/*
	 * Initialization failed because of an OS\2 exec failure on 
	 *  path %1. The OS\2 error code is the data.
	 */

#define NELOG_Ncb_Error			(ERRLOG_BASE + 6)
	/*
	 * An unexpected NCB was received. The NCB is the data.
	 */

#define NELOG_Net_Not_Started		(ERRLOG_BASE + 7)
	/*
 	 * The network is not started.
	 */

#define NELOG_Ioctl_Error		(ERRLOG_BASE + 8)
	/*
 	 * DosDevIoctl to the redirector failed.
	 *	data is:  DWORD  approx CS:IP of call to ioctl
	 *		  WORD   error code
	 *		  WORD   ioctl number
	 */

#define NELOG_System_Semaphore		(ERRLOG_BASE + 9)
	/*
	 * Unable to create or open system semaphore %1.
	 *  The error code is the data.
	 */

#define NELOG_Init_OpenCreate_Err	(ERRLOG_BASE + 10)
	/*
	 * Initialization failed because of an open/create error on the
	 *  file %1. The OS/2 error code is in the data.
	 */

#define NELOG_NetBios			(ERRLOG_BASE + 11)
	/*
	 * An unexpected NetBios error occurred.
	 *  The error code is the data.
	 */

#define NELOG_SMB_Illegal		(ERRLOG_BASE + 12)
	/*
	 * An illegal SMB was received.
	 *  The SMB is the data.
	 */

#define NELOG_Service_Fail		(ERRLOG_BASE + 13)
	/*
	 * Initialization failed because the requested service %1 
	 *  could not be installed.
	 */

#define NELOG_Entries_Lost		(ERRLOG_BASE + 14)
	/*
 	 * Some error log entries have been lost due to buffer overflow.
	 */


/*
 *	Server specific error log messages from 20 to 40
 */

#define NELOG_Init_Seg_Overflow		(ERRLOG_BASE + 20)
	/*
	 * Initialization parameters controlling resource usage other
	 *  than net buffers are sized so that too much memory is needed. 
	 */

#define NELOG_Srv_No_Mem_Grow		(ERRLOG_BASE + 21)
	/* 
	 * The Server cannot increase the size of a memory segment.
	 */

#define NELOG_Access_File_Bad		(ERRLOG_BASE + 22)
	/*
	 * Initialization failed because account file: %1 is either incorrect
	 * or not present.
	 */

#define NELOG_Srvnet_Not_Started	(ERRLOG_BASE + 23)
	/*
	 * Initialization failed because network: %1 was not started.
	 */

#define NELOG_Init_Chardev_Err		(ERRLOG_BASE + 24)
	/*
	 * The Server failed to install. Either all three chdev 
	 *  parameters must be zero or all three must be nonzero.
	 */

#define NELOG_Remote_API		(ERRLOG_BASE + 25)
	/* A remote API request was halted due to the following
	 * invalid description string: %1.
	 */

#define NELOG_Ncb_TooManyErr		(ERRLOG_BASE + 26)
	/* The network described by %1 has run out of ncb's.  Suggest you
	 *  increase the configured ncb's for this net.  The raw data
	 *  contains the count of server submitted ncb's at the time of
	 *  the error.
	 */

#define NELOG_Mailslot_err		(ERRLOG_BASE + 27)
	/* There was an error creating the mailslot %1.  
	 * The server cannot process the RELEASEMEMORY alert.  The error 
	 * is in the data.
	 */

#define NELOG_ReleaseMem_Alert		(ERRLOG_BASE + 28)
	/* The server failed to register for the RELEASEMEMORY alert,
	 * with recipient %1.  The error code from 
	 * NetAlertStart is in the data.
	 */

#define NELOG_AT_cannot_write		(ERRLOG_BASE + 29)
	/* The server cannot update the AT schedule file.  The file
	 * is corrupt.
	 */

/*
 *	Message service and POPUP specific error log messages from 40 to 55
 */

#define NELOG_Msg_Shutdown		(ERRLOG_BASE + 40)
	/*
	 * The service has stopped due to repeated consecutive
	 *  occurrences of an NCB error. NCB follows in raw data.
	 */
	 
#define NELOG_Msg_Sem_Shutdown		(ERRLOG_BASE + 41)
	/*
	 * The Message Server has stopped due to a lock on the
	 *  Message Server shared data segment.
	 */

#define	NELOG_Msg_Log_Err		(ERRLOG_BASE + 50)
	/*
	 * A file system error occurred while opening or writing to the 
	 *  system message log file, %1. Message logging has been 
	 *  switched off due to the error. The error code is the data.
	 */


#define NELOG_VIO_POPUP_ERR		(ERRLOG_BASE + 51)
	/*
	 * Unable to display message POPUP due to OS/2 VIO call error.
	 *  The error code is the data.
	 */


#define	NELOG_Msg_Unexpected_SMB_Type	(ERRLOG_BASE + 52)
	/*
	 * An illegal SMB was received.
	 *  The SMB is the data.
	 */

	
/*
 *	Workstation specific error log messages from 60 to 75
 */


#define NELOG_Wksta_Infoseg		(ERRLOG_BASE + 60)
	/*
	 * The Workstation information segment is bigger than 64k bytes.
	 *  The DWORD size is the data.
	 */

#define NELOG_Wksta_Compname		(ERRLOG_BASE + 61)
	/*
	 * The Workstation was unable to get the name-number of computer name.
	 */

#define NELOG_Wksta_BiosThreadFailure	(ERRLOG_BASE + 62)
	/*
	 * The Workstation could not initialize the Async NetBios Thread
	 *  The error code is the data.
	 */

#define NELOG_Wksta_IniSeg		(ERRLOG_BASE + 63)
	/*
	 * The Workstation could not open the initial shared segment.
	 *  The error code is the data.
	 */


#define NELOG_Wksta_HostTab_Full	(ERRLOG_BASE + 64)
	/*
	 * The Workstation host table is full.
	 */


#define NELOG_Wksta_Bad_Mailslot_SMB	(ERRLOG_BASE + 65)
	/*
	 * A bad mailslot SMB was received.
	 *  The SMB is the data.
	 */



/*
 *	Alerter service specific error log messages from 70 to 79
 */


#define NELOG_Build_Name		(ERRLOG_BASE + 70)
	/*
	 * There was an error in building the list of names to alert. The
	 *  error code is %1.
	 */

#define NELOG_Name_Expansion		(ERRLOG_BASE + 71)
	/*
	 * There was an error expanding %1 as a group name. Try
	 *  splitting the group into two or more smaller groups.
	 */


#define NELOG_Message_Send		(ERRLOG_BASE + 72)
	/*
	 * There was an error sending %2 the alert message -
	 *  (
	 *  %3 )
	 *  The error code is %1.
	 */


#define NELOG_Mail_Slt_Err		(ERRLOG_BASE + 73)
	/*
	 * There was an error in creating or reading the alerter mailslot.
	 *  The error code is %1.
	 */



#define NELOG_AT_cannot_read		(ERRLOG_BASE + 74)
	/*
	 * The Server could not read the AT schedule file.
	 */

#define NELOG_AT_sched_err		(ERRLOG_BASE + 75)
	/*
	 * The Server found an invalid AT schedule record.
	 */

#define NELOG_AT_schedule_file_created	(ERRLOG_BASE + 76)
	/*
	 * The Server could not find an AT schedule file so it created one.
	 */

#define NELOG_Srvnet_NB_Open		(ERRLOG_BASE + 77)
	/*
	 * The Server could not NetBiosOpen network %1.
	 */

#define NELOG_AT_Exec_Err		(ERRLOG_BASE + 78)
	/*
	 * The AT processor could not exec %1.
         */

/*
 *      Cache Lazy Write specific error log messages from 80 to 84
 */

#define NELOG_Lazy_Write_Err            (ERRLOG_BASE + 80)
        /*
         * WARNING : The Lazy Write process encountered an error when
         *           writing to drive %1. The disk contains corrupted
         *           data. The cache has been stopped.
         */


/*
 *	Netwksta.sys specific error log messages from 90 to 99
 */

#define NELOG_NetWkSta_Internal_Error	(ERRLOG_BASE + 90)
	/*
	 * A NetWksta internal error has occurred:
	 *  %1
	 */

#define NELOG_NetWkSta_No_Resource	(ERRLOG_BASE + 91)
	/*
	 * The redirector is out of a resource: %1.
	 */

#define NELOG_NetWkSta_SMB_Err		(ERRLOG_BASE + 92)
	/*
	 * An SMB error occurred on connection to %1.
	 *  The SMB header is the data.
	 */

#define NELOG_NetWkSta_VC_Err		(ERRLOG_BASE + 93)
	/*
	 * A Virtual Circuit error occurred on the session to %1.
	 *  The NCB command and return code is the data.
	 */

#define NELOG_NetWkSta_Stuck_VC_Err	(ERRLOG_BASE + 94)
	/*
	 * Hanging up a stuck session to %1.
	 */

#define NELOG_NetWkSta_NCB_Err		(ERRLOG_BASE + 95)
	/*
	 * An NCB error occurred (%1).
	 *  The NCB is the data.
	 */

#define NELOG_NetWkSta_Write_Behind_Err	(ERRLOG_BASE + 96)
	/*
	 * A write operation to %1 failed.
	 *  Data may have been lost.
	 */

#define NELOG_NetWkSta_Reset_Err	(ERRLOG_BASE + 97)
	/*
	 * Reset of driver %1 failed to complete the NCB.
	 *  The NCB is the data.
	 */

#define	NELOG_NetWkSta_Too_Many		(ERRLOG_BASE + 98)
	/*
         * The amount of resource %1 requested was more 
	 *  than the maximum. The maximum amount was allocated.
	 */

/*
/*
 *	Spooler specific error log messages from 100 to 109
 */

#define NELOG_Spooler_Exec_Failed		(ERRLOG_BASE + 100)
	/*
	 * The exec of SPOOLER.EXE failed.
	 */

#define NELOG_Cannot_Make_Spooldir		(ERRLOG_BASE + 101)
	/*
	 * Spooler initialization cannot make the spool directory.
	 */

#define NELOG_Spooler_Handshake_Failed		(ERRLOG_BASE + 102)
	/*
	 * The Spooler did not handshake with initialization process.
	 */

#define NELOG_Q_Config_Error			(ERRLOG_BASE + 103)
	/*
	 * A print queue %1 configuration error occurred. 
	 *  The %2 file cannot be found.
	 */

#define NELOG_Srv_Thread_Failure		(ERRLOG_BASE + 104)
	/*
	 * The server could not create a thread.
	 *  The THREADS parameter in CONFIG.SYS should be increased.
	 */

#define NELOG_Srv_Close_Failure 		(ERRLOG_BASE + 105)
	/*
	 * The server could not close %1.
	 *  The file is probably corrupt.
	 */
	 
#define NELOG_Srv_DBToo_Small                   (ERRLOG_BASE + 106)
	/*
         * The user access file is not large enough to hold all the user
         *  and group information.
	 */
	 
#define NELOG_Srv_Encryp_Err                    (ERRLOG_BASE + 107)
	/*
         * There is an encryption problem.
         *  Your Server/Redirector combination may be incompatible.
	 */
	 
/**************************************************************** 
 * Microsoft has created a generic error log entry for OEMs to use to
 * log errors from OEM value added services.  The code, which is the
 * 2nd arg to NetErrorLogWrite, is 3299.  This value is manifest in
 * net/h/errlog.h as NELOG_OEM_Code.  The text for error log entry
 * NELOG_OEM_Code is:  "%1 %2 %3 %4 %5 %6 %7 %8 %9.".
 * 
 * Microsoft suggests that OEMs use the insertion strings as follows:
 * %1:  OEM System Name (e.g. 3+Open)
 * %2:  OEM Service Name (e.g. 3+Mail)
 * %3:  Severity level (e.g.  error, warning, etc.)
 * %4:  OEM error log entry sub-identifier  (e.g. error code #)
 * %5 - % 9:  Text.
 * 
 * The call to NetErrorWrite must set nstrings = 9, and provide 9
 * ASCIIZ strings.  If the caller does not have 9 insertion strings,
 * provide null strings for the empty insertion strings.
 ****************************************************************/

#define NELOG_OEM_Code 				(ERRLOG_BASE + 199)
	/*
	 * %1 %2 %3 %4 %5 %6 %7 %8 %9.
	 */
